@@ -13,8 +13,9 @@ use Carp         'confess';
 use Scalar::Util 'blessed', 'reftype', 'weaken';
 use Sub::Name    'subname';
 use Devel::GlobalDestruction 'in_global_destruction';
+use Try::Tiny;
 
-our $VERSION   = '0.93';
+our $VERSION   = '0.95';
 $VERSION = eval $VERSION;
 our $AUTHORITY = 'cpan:STEVAN';
 
@@ -328,7 +329,7 @@ sub create {
 # all these attribute readers will be bootstrapped
 # away in the Class::MOP bootstrap section
 
-sub get_attribute_map        { $_[0]->{'attributes'}                  }
+sub _attribute_map           { $_[0]->{'attributes'}                  }
 sub attribute_metaclass      { $_[0]->{'attribute_metaclass'}         }
 sub instance_metaclass       { $_[0]->{'instance_metaclass'}          }
 sub immutable_trait          { $_[0]->{'immutable_trait'}             }
@@ -595,7 +596,7 @@ sub class_precedence_list {
 
     sub add_before_method_modifier {
         my ($self, $method_name, $method_modifier) = @_;
-        (defined $method_name && $method_name)
+        (defined $method_name && length $method_name)
             || confess "You must pass in a method name";
         my $method = $fetch_and_prepare_method->($self, $method_name);
         $method->add_before_modifier(
@@ -605,7 +606,7 @@ sub class_precedence_list {
 
     sub add_after_method_modifier {
         my ($self, $method_name, $method_modifier) = @_;
-        (defined $method_name && $method_name)
+        (defined $method_name && length $method_name)
             || confess "You must pass in a method name";
         my $method = $fetch_and_prepare_method->($self, $method_name);
         $method->add_after_modifier(
@@ -615,7 +616,7 @@ sub class_precedence_list {
 
     sub add_around_method_modifier {
         my ($self, $method_name, $method_modifier) = @_;
-        (defined $method_name && $method_name)
+        (defined $method_name && length $method_name)
             || confess "You must pass in a method name";
         my $method = $fetch_and_prepare_method->($self, $method_name);
         $method->add_around_modifier(
@@ -639,7 +640,7 @@ sub class_precedence_list {
 
 sub find_method_by_name {
     my ($self, $method_name) = @_;
-    (defined $method_name && $method_name)
+    (defined $method_name && length $method_name)
         || confess "You must define a method name to find";
     foreach my $class ($self->linearized_isa) {
         my $method = $self->initialize($class)->get_method($method_name);
@@ -670,7 +671,7 @@ sub get_all_method_names {
 
 sub find_all_methods_by_name {
     my ($self, $method_name) = @_;
-    (defined $method_name && $method_name)
+    (defined $method_name && length $method_name)
         || confess "You must define a method name to find";
     my @methods;
     foreach my $class ($self->linearized_isa) {
@@ -687,7 +688,7 @@ sub find_all_methods_by_name {
 
 sub find_next_method_by_name {
     my ($self, $method_name) = @_;
-    (defined $method_name && $method_name)
+    (defined $method_name && length $method_name)
         || confess "You must define a method name to find";
     my @cpl = $self->linearized_isa;
     shift @cpl; # discard ourselves
@@ -728,23 +729,21 @@ sub add_attribute {
     
     # get our count of previously inserted attributes and
     # increment by one so this attribute knows its order
-    my $order = (scalar keys %{$self->get_attribute_map});
+    my $order = (scalar keys %{$self->_attribute_map});
     $attribute->_set_insertion_order($order);
 
     # then onto installing the new accessors
-    $self->get_attribute_map->{$attr_name} = $attribute;
+    $self->_attribute_map->{$attr_name} = $attribute;
 
     # invalidate package flag here
-    my $e = do {
-        local $@;
+    try {
         local $SIG{__DIE__};
-        eval { $attribute->install_accessors() };
-        $@;
-    };
-    if ( $e ) {
-        $self->remove_attribute($attr_name);
-        die $e;
+        $attribute->install_accessors();
     }
+    catch {
+        $self->remove_attribute($attr_name);
+        die $_;
+    };
 
     return $attribute;
 }
@@ -814,14 +813,14 @@ sub has_attribute {
     my ($self, $attribute_name) = @_;
     (defined $attribute_name)
         || confess "You must define an attribute name";
-    exists $self->get_attribute_map->{$attribute_name};
+    exists $self->_attribute_map->{$attribute_name};
 }
 
 sub get_attribute {
     my ($self, $attribute_name) = @_;
     (defined $attribute_name)
         || confess "You must define an attribute name";
-    return $self->get_attribute_map->{$attribute_name}
+    return $self->_attribute_map->{$attribute_name}
     # NOTE:
     # this will return undef anyway, so no need ...
     #    if $self->has_attribute($attribute_name);
@@ -832,9 +831,9 @@ sub remove_attribute {
     my ($self, $attribute_name) = @_;
     (defined $attribute_name)
         || confess "You must define an attribute name";
-    my $removed_attribute = $self->get_attribute_map->{$attribute_name};
+    my $removed_attribute = $self->_attribute_map->{$attribute_name};
     return unless defined $removed_attribute;
-    delete $self->get_attribute_map->{$attribute_name};
+    delete $self->_attribute_map->{$attribute_name};
     $self->invalidate_meta_instances();
     $removed_attribute->remove_accessors();
     $removed_attribute->detach_from_class();
@@ -843,12 +842,12 @@ sub remove_attribute {
 
 sub get_attribute_list {
     my $self = shift;
-    keys %{$self->get_attribute_map};
+    keys %{$self->_attribute_map};
 }
 
 sub get_all_attributes {
     my $self = shift;
-    my %attrs = map { %{ $self->initialize($_)->get_attribute_map } } reverse $self->linearized_isa;
+    my %attrs = map { %{ $self->initialize($_)->_attribute_map } } reverse $self->linearized_isa;
     return values %attrs;
 }
 
@@ -1163,7 +1162,7 @@ Class::MOP::Class - Class Meta Object
 The Class Protocol is the largest and most complex part of the
 Class::MOP meta-object protocol. It controls the introspection and
 manipulation of Perl 5 classes, and it can create them as well. The
-best way to understand what this module can do, is to read the
+best way to understand what this module can do is to read the
 documentation for each of its methods.
 
 =head1 INHERITANCE
@@ -1175,7 +1174,7 @@ C<Class::MOP::Class> is a subclass of L<Class::MOP::Module>.
 =head2 Class construction
 
 These methods all create new C<Class::MOP::Class> objects. These
-objects can represent existing classes, or they can be used to create
+objects can represent existing classes or they can be used to create
 new classes from scratch.
 
 The metaclass object for a given class is a singleton. If you attempt
@@ -1187,7 +1186,7 @@ existing object.
 =item B<< Class::MOP::Class->create($package_name, %options) >>
 
 This method creates a new C<Class::MOP::Class> object with the given
-package name. It accepts a number of options.
+package name. It accepts a number of options:
 
 =over 8
 
@@ -1206,7 +1205,7 @@ An optional array reference of superclass names.
 =item * methods
 
 An optional hash reference of methods for the class. The keys of the
-hash reference are method names, and values are subroutine references.
+hash reference are method names and values are subroutine references.
 
 =item * attributes
 
@@ -1231,7 +1230,7 @@ All instances of an anonymous class keep a special reference to the
 metaclass object, which prevents the metaclass from going out of scope
 while any instances exist.
 
-This only works if the instance if based on a hash reference, however.
+This only works if the instance is based on a hash reference, however.
 
 =item B<< Class::MOP::Class->initialize($package_name, %options) >>
 
@@ -1301,12 +1300,11 @@ class. Any parameters you provide are used to initialize the
 instance's attributes. A special C<__INSTANCE__> key can be passed to
 provide an already generated instance, rather than having Class::MOP
 generate it for you. This is mostly useful for using Class::MOP with
-foreign classes, which generally generate instances using their own
-constructor.
+foreign classes which generate instances using their own constructors.
 
 =item B<< $metaclass->instance_metaclass >>
 
-Returns the class name of the instance metaclass, see
+Returns the class name of the instance metaclass. See
 L<Class::MOP::Instance> for more information on the instance
 metaclass.
 
@@ -1448,12 +1446,6 @@ Returns a boolean indicating whether or not the class defines the
 named attribute. It does not include attributes inherited from parent
 classes.
 
-=item B<< $metaclass->get_attribute_map >>
-
-Returns a hash reference representing the attributes defined in this
-class. The keys are attribute names and the values are
-L<Class::MOP::Attribute> objects.
-
 =item B<< $metaclass->get_attribute_list >>
 
 This will return a list of attributes I<names> for all attributes
@@ -1468,7 +1460,7 @@ the L<Class::MOP::Attribute> objects for this class and its parents.
 
 This will return a L<Class::MOP::Attribute> for the specified
 C<$attribute_name>. If the class does not have the specified
-attribute, it returns C<undef>
+attribute, it returns C<undef>.
 
 Unlike C<get_attribute>, this attribute I<will> look for the named
 attribute in superclasses.
@@ -1476,7 +1468,7 @@ attribute in superclasses.
 =item B<< $metaclass->add_attribute(...) >>
 
 This method accepts either an existing L<Class::MOP::Attribute>
-object, or parameters suitable for passing to that class's C<new>
+object or parameters suitable for passing to that class's C<new>
 method.
 
 The attribute provided will be added to the class.
@@ -1516,8 +1508,8 @@ methods, and also allows us to optimize some methods on the metaclass
 object itself.
 
 After immutabilization, the metaclass object will cache most informational
-methods that returns information about methods or attributes.. Methods which
-would alter the class, such as C<add_attribute>, C<add_method>, and so on will
+methods that returns information about methods or attributes. Methods which
+would alter the class, such as C<add_attribute> and C<add_method>, will
 throw an error on an immutable metaclass object.
 
 The immutabilization system in L<Moose> takes much greater advantage
@@ -1527,7 +1519,7 @@ of the inlining features than Class::MOP itself does.
 
 =item B<< $metaclass->make_immutable(%options) >>
 
-This method will create an immutable transformer and uses it to make
+This method will create an immutable transformer and use it to make
 the class and its metaclass object immutable.
 
 This method accepts the following options:
@@ -1600,7 +1592,7 @@ Calling this method reverse the immutabilization transformation.
 
 Method modifiers are hooks which allow a method to be wrapped with
 I<before>, I<after> and I<around> method modifiers. Every time a
-method is called, it's modifiers are also called.
+method is called, its modifiers are also called.
 
 A class can modify its own methods, as well as methods defined in
 parent classes.
@@ -1644,9 +1636,9 @@ order. So the call tree might looks something like this:
 
 Of course there is a performance cost associated with method
 modifiers, but we have made every effort to make that cost directly
-proportional to the number of modifier features you utilize.
+proportional to the number of modifier features you use.
 
-The wrapping method does it's best to B<only> do as much work as it
+The wrapping method does its best to B<only> do as much work as it
 absolutely needs to. In order to do this we have moved some of the
 performance costs to set-up time, where they are easier to amortize.
 
